import{d as s,a5 as m,x as n,V as e,c as l,h as c,f as u,b as f}from"./index-CQHe9KB5.js";import{I as h}from"./ItemsListing-D0RDJqR8.js";import"./VCheckbox-_eVssUuR.js";import"./eventbus-CxBHXMjo.js";import"./VListItem-932LEcae.js";import"./VCheckboxBtn-WpBm-DQx.js";import"./VList-SeV0eskX.js";import"./VCardText-BC98CPwQ.js";import"./VCard-BBArKN8n.js";import"./VMenu-C_g4AWFG.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./ListItem-BlTvbW6N.js";import"./Button-C2tPqXAJ.js";import"./VSpacer-BB-V2OH5.js";/* empty css              */import"./PanelviewItemCompact-C9xC4OzX.js";import"./VAlert-CgwdfNK_.js";import"./Container-D0GZf7eO.js";import"./Toolbar-Bxz1a-Vc.js";import"./VToolbar-AihbUtg2.js";import"./VTextField-DJj81lxi.js";import"./VInfiniteScroll-tYOoNmCo.js";import"./layout-BxB_31nW.js";import"./VVirtualScroll-qRehF0qb.js";const K=s({__name:"BrowseView",props:{path:{}},setup(i){const t=i,{t:o}=m(),a=n(()=>!t.path||t.path=="root"?o("browse"):e("bp6")?o("browse")+" | "+t.path:e("bp3")?t.path:o("browse")),p=async function(r){return await f.browse(t.path)};return(r,w)=>(l(),c("section",null,[u(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":p,"sort-keys":["original","name","name_desc"],title:a.value,path:r.path,"allow-key-hooks":!0,icon:"mdi-folder-outline"},null,8,["title","path"])]))}});export{K as default};
